@@ -1,3 +1,4 @@
+import sys
 from collections import deque
 from dataclasses import dataclass, field
 from datetime import datetime
@@ -15,6 +16,10 @@ from typing import (Collection,
                     Union,
                     Any)
 from uuid import UUID
+if sys.version_info >= (3, 9):
+    from collections import Counter
+else:
+    from typing import Counter
 
 from marshmallow import fields
 
@@ -156,6 +161,11 @@ class DataClassWithOptional(DataClassJsonMixin):
     x: Optional[int]
 
 
+@dataclass(frozen=True)
+class DataClassWithOptionalWithDefault(DataClassJsonMixin):
+    x: Optional[int] = None
+
+
 @dataclass(frozen=True)
 class DataClassWithOptionalUnbound(DataClassJsonMixin):
     x: Optional
@@ -171,6 +181,11 @@ class DataClassWithOptionalNested(DataClassJsonMixin):
     x: Optional[DataClassWithOptional]
 
 
+@dataclass(frozen=True)
+class DataClassWithOptionalNestedWithDefault(DataClassJsonMixin):
+    x: Optional[DataClassWithOptional] = None
+
+
 @dataclass(frozen=True)
 class DataClassWithUnionIntNone(DataClassJsonMixin):
     x: Union[int, None]
@@ -254,6 +269,29 @@ class DataClassWithConfigHelper:
     id: float = field(metadata=config(encoder=str))
 
 
+@dataclass_json
+@dataclass
+class DataClassWithErroneousDecode:
+    # Accepts no arguments, so passing in a single argument will result in a TypeError.
+    id: float = field(metadata=config(decoder=lambda: None))
+
+
+def split_str(data: str, *_args, **_kwargs):
+    return data.split(',')
+
+
+@dataclass_json
+@dataclass
+class DataClassDifferentTypeDecode:
+    lst: List[str] = field(default=None, metadata=config(decoder=split_str))
+
+
+@dataclass_json
+@dataclass
+class DataClassMappingBadDecode:
+    map: Dict[str, DataClassWithErroneousDecode]
+
+
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass
 class DataClassWithConfigDecorator:
@@ -337,3 +375,16 @@ class DataClassWithNestedOptional:
 @dataclass
 class DataClassWithNestedDictWithTupleKeys:
     a: Dict[Tuple[int], int]
+
+
+@dataclass_json
+@dataclass
+class DataClassWithCounter:
+    c: Counter[str]
+
+
+@dataclass_json
+@dataclass
+class DataClassWithSelf(DataClassJsonMixin):
+    id: str
+    ref: Optional['DataClassWithSelf']
