@@ -37,12 +37,24 @@ class Aux2:
     f1: str
 
 
+@dataclass_json
+@dataclass
+class Aux3:
+    f2: str
+
+
 @dataclass_json
 @dataclass
 class C4:
     f1: Union[Aux1, Aux2]
 
 
+@dataclass_json
+@dataclass
+class C12:
+    f1: Union[Aux2, Aux3]
+
+
 @dataclass_json
 @dataclass
 class C5:
@@ -114,6 +126,31 @@ except TypeError:
         """
         f1: Union[str, None] = None
 
+
+@dataclass_json
+@dataclass
+class C13:
+    data: str
+
+
+@dataclass_json
+@dataclass
+class C14:
+    content: str
+
+
+@dataclass_json
+@dataclass
+class C15:
+    data: C13
+
+
+@dataclass_json
+@dataclass
+class C16:
+    event: Union[C15, C13]
+
+
 params = [
     (C1(f1=12), {"f1": 12}, '{"f1": 12}'),
     (C1(f1="str1"), {"f1": "str1"}, '{"f1": "str1"}'),
@@ -198,3 +235,44 @@ def test_deserialize_with_error(cls, data):
     s = cls.schema()
     with pytest.raises(ValidationError):
         assert s.load(data)
+
+
+def test_deserialize_without_discriminator():
+    # determine based on type
+    json = '{"f1": {"f1": 1}}'
+    s = C4.schema()
+    obj = s.loads(json)
+    assert obj.f1 is not None
+    assert type(obj.f1) == Aux1
+
+    json = '{"f1": {"f1": "str1"}}'
+    s = C4.schema()
+    obj = s.loads(json)
+    assert obj.f1 is not None
+    assert type(obj.f1) == Aux2
+
+    # determine based on field name
+    json = '{"f1": {"f1": "str1"}}'
+    s = C12.schema()
+    obj = s.loads(json)
+    assert obj.f1 is not None
+    assert type(obj.f1) == Aux2
+    json = '{"f1": {"f2": "str1"}}'
+    s = C12.schema()
+    obj = s.loads(json)
+    assert obj.f1 is not None
+    assert type(obj.f1) == Aux3
+
+    # if no matching types, type should remain dict
+    json = '{"f1": {"f3": "str2"}}'
+    s = C12.schema()
+    obj = s.loads(json)
+    assert type(obj.f1) == dict
+
+
+def test_deserialize_with_mismatched_field_types():
+    json = '{"event": {"data": "Hello world!"} }'
+    s = C16.schema()
+    obj = s.loads(json)
+    assert obj.event is not None
+    assert obj.event.data == "Hello world!"
